@@ -622,11 +622,13 @@ btnum_to_ops(
 {
 	switch (btnum) {
 	case XFS_BTNUM_BNO:
+		return &xfs_bnobt_buf_ops;
 	case XFS_BTNUM_CNT:
-		return &xfs_allocbt_buf_ops;
+		return &xfs_cntbt_buf_ops;
 	case XFS_BTNUM_INO:
-	case XFS_BTNUM_FINO:
 		return &xfs_inobt_buf_ops;
+	case XFS_BTNUM_FINO:
+		return &xfs_finobt_buf_ops;
 	case XFS_BTNUM_RMAP:
 		return &xfs_rmapbt_buf_ops;
 	case XFS_BTNUM_REFC:
